@@ -1,44 +1,53 @@
-# coding: utf-8
 """
     cairocffi
     ~~~~~~~~~
 
     CFFI-based cairo bindings for Python. See README for details.
 
-    :copyright: Copyright 2013 by Simon Sapin
+    :copyright: Copyright 2013-2019 by Simon Sapin
     :license: BSD, see LICENSE for details.
 
 """
 
 import sys
-import ctypes.util
+from ctypes.util import find_library
+from pathlib import Path
 
 from . import constants
-from .compat import FileNotFoundError
-from ._ffi import ffi
+from ._generated.ffi import ffi
 
-VERSION = '0.9.0'
+VERSION = __version__ = (Path(__file__).parent / 'VERSION').read_text().strip()
 # supported version of cairo, used to be pycairo version too:
-version = '1.16.0'
-version_info = (1, 16, 0)
+version = '1.17.2'
+version_info = (1, 17, 2)
 
 
-def dlopen(ffi, *names):
+def dlopen(ffi, library_names, filenames):
     """Try various names for the same library, for different platforms."""
-    for name in names:
-        for lib_name in [name, 'lib' + name]:
-            try:
-                path = ctypes.util.find_library(lib_name)
-                if path:
-                    lib = ffi.dlopen(path)
-                    if lib:
-                        return lib
-            except OSError:
-                pass
-    raise OSError("dlopen() failed to load a library: %s" % ' / '.join(names))
+    exceptions = []
+
+    for library_name in library_names:
+        library_filename = find_library(library_name)
+        if library_filename:
+            filenames = (library_filename,) + filenames
+        else:
+            exceptions.append(
+                'no library called "{}" was found'.format(library_name))
+
+    for filename in filenames:
+        try:
+            return ffi.dlopen(filename)
+        except OSError as exception:  # pragma: no cover
+            exceptions.append(exception)
+
+    error_message = '\n'.join(  # pragma: no cover
+        str(exception) for exception in exceptions)
+    raise OSError(error_message)  # pragma: no cover
 
 
-cairo = dlopen(ffi, 'cairo', 'cairo-2', 'cairo-gobject-2')
+cairo = dlopen(
+    ffi, ('cairo', 'libcairo-2'),
+    ('libcairo.so.2', 'libcairo.2.dylib', 'libcairo-2.dll'))
 
 
 class _keepref(object):
@@ -109,17 +118,19 @@ def install_as_pycairo():
 
 # Implementation is in submodules, but public API is all here.
 
-from .surfaces import (Surface, ImageSurface, PDFSurface, PSSurface,
-                       SVGSurface, RecordingSurface, Win32Surface,
-                       Win32PrintingSurface)
+from .surfaces import (  # noqa isort:skip
+    Surface, ImageSurface, PDFSurface, PSSurface, SVGSurface, RecordingSurface,
+    Win32Surface, Win32PrintingSurface)
 try:
-    from .xcb import XCBSurface
+    from .xcb import XCBSurface  # noqa isort:skip
 except ImportError:
     pass
-from .patterns import (Pattern, SolidPattern, SurfacePattern,
-                       Gradient, LinearGradient, RadialGradient)
-from .fonts import FontFace, ToyFontFace, ScaledFont, FontOptions
-from .context import Context
-from .matrix import Matrix
+from .patterns import (  # noqa isort:skip
+    Pattern, SolidPattern, SurfacePattern, Gradient, LinearGradient,
+    RadialGradient)
+from .fonts import (  # noqa isort:skip
+    FontFace, ToyFontFace, ScaledFont, FontOptions)
+from .context import Context  # noqa isort:skip
+from .matrix import Matrix  # noqa isort:skip
 
-from .constants import *
+from .constants import *  # noqa isort:skip
